% SweepSource.m
%
% author:  Greg Durgin (1/26/2012)
%
% This file sweeps a transmission line with a non-linear load through a
% range of input resistance values and plots the steady state output
% voltages.
%

% Basic tline parameters
T = 1e-9;           % transmission line transit time
Z0 = 50;            % intrinsic impedance of line
Vs = .2;            % voltage of DC source switched at t=0
Rs1 = -32.0;        % range of source resistances to try
Rs2 = 20.0;


% Initialize matrices
Rs = Rs1:.1:Rs2;    % source impedance
V = [];             % null initialize

% Step through all possible source resistances
for i = 1:length(Rs)  
    Vtemp = NonlinearTlinePlot( T, Z0, Vs, Rs(i) )';
    V = [ V; Vtemp(100:end) ];      % ignore the first 100T to get Q-point
end;

% Plot the quiescent behavior as a function of reflection coefficient
GammaS = (Rs-Z0)./(Rs+Z0);
figure(2); plot(GammaS, V, 'k.');
axis( [ min(GammaS) max(GammaS) min(min(V))  max(max(V))] );
set(gca,'FontSize',14);
xlabel( 'Source Reflection Coefficient' );
ylabel( 'Voltage (V)');
title( 'Transmission Line output terminated with tunnel diode');
